==> guile-gtk-0.60_8.tbz: share/guile/gtk-1.2/config.scm <==
;; Copyright (C) 2003 Free Software Foundation, Inc.
;;
;; This program is free software; you can redistribute it and/or
;; modify it under the terms of the GNU General Public License as
;; published by the Free Software Foundation; either version 2 of
;; the License, or (at your option) any later version.
;; 
;; This program is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.
;; 
;; You should have received a copy of the GNU General Public
;; License along with this program; if not, write to the Free Software
;; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

(define-module (gtk-1.2 config))

(define-public gtkconf-prefix "/usr/local")
(define-public gtkconf-exec-prefix "${prefix}")
(define-public gtkconf-libdir "${prefix}/lib")
(define-public gtkconf-default-version "@GTK_VERSION@")
(define-public gtkconf-version "1.2")
(define-public gtkconf-gtk-2-0 #f)
(define-public gtkconf-guile-gtk-version "0.60")
(define-public gtkconf-guilegtk-lib "-lguilegtk-1.2")
(define-public gtkconf-guile-libs "-I/usr/local/include -D_THREAD_SAFE -pthread -L/usr/local/lib -lguile -lltdl -L/usr/local/lib -rpath=/usr/lib:/usr/local/lib -lgmp -lcrypt -lm -lltdl")
(define-public gtkconf-gtk-libs "-L/usr/local/lib -L/usr/local/lib -lgtk-12 -lgdk-12 -lgmodule-12 -lgthread-12 -lglib-12 -pthread -lintl -lXi -lXext -lX11 -lm")
(define-public gtkconf-cc "cc")
(define-public gtkconf-gtk-cflags "-I/usr/local/include/gtk12 -I/usr/local/include/glib12 -I/usr/local/include -I/usr/local/include")

==> guile-gtk-0.60_9.tbz: share/guile/gtk-1.2/config.scm <==
;; Copyright (C) 2003 Free Software Foundation, Inc.
;;
;; This program is free software; you can redistribute it and/or
;; modify it under the terms of the GNU General Public License as
;; published by the Free Software Foundation; either version 2 of
;; the License, or (at your option) any later version.
;; 
;; This program is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.
;; 
;; You should have received a copy of the GNU General Public
;; License along with this program; if not, write to the Free Software
;; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

(define-module (gtk-1.2 config))

(define-public gtkconf-prefix "/usr/local")
(define-public gtkconf-exec-prefix "${prefix}")
(define-public gtkconf-libdir "${prefix}/lib")
(define-public gtkconf-default-version "@GTK_VERSION@")
(define-public gtkconf-version "1.2")
(define-public gtkconf-gtk-2-0 #f)
(define-public gtkconf-guile-gtk-version "0.60")
(define-public gtkconf-guilegtk-lib "-lguilegtk-1.2")
(define-public gtkconf-guile-libs "-I/usr/local/include -D_THREAD_SAFE -pthread -L/usr/local/lib -lguile -lltdl -L/usr/local/lib -Wl,-rpath=/usr/lib:/usr/local/lib -lgmp -lcrypt -lm -lltdl")
(define-public gtkconf-gtk-libs "-L/usr/local/lib -L/usr/local/lib -lgtk-12 -lgdk-12 -lgmodule-12 -lgthread-12 -lglib-12 -pthread -lintl -lXi -lXext -lX11 -lm")
(define-public gtkconf-cc "cc")
(define-public gtkconf-gtk-cflags "-I/usr/local/include/gtk12 -I/usr/local/include/glib12 -D_REENTRANT -I/usr/local/include -I/usr/local/include")
